@@ -33,5 +33,5 @@ class Reports(APIEndpoint):
         while result["ready"] is not True:
             print(f"Ready: {result['ready']} for Job ID: {result['id']}.")
             result = self._get().json()
-            time.sleep(self._query_delay)
+            time.sleep(kwargs.get('query_delay', self._query_delay))
         return result
