@@ -4,6 +4,7 @@ from restfly.session import APISession
 
 from skytapsdk.api_endpoints.assets import Assets
 from skytapsdk.api_endpoints.environments import Environments
+from skytapsdk.api_endpoints.reports import Reports
 from skytapsdk.api_endpoints.templates import Templates
 from skytapsdk.api_endpoints.users import Users
 
@@ -101,3 +102,7 @@ class Skytap(APISession):
     @property
     def assets(self) -> Assets:
         return Assets(self)
+
+    @property
+    def reports(self) -> Reports:
+        return Reports(self)
